==> medialibrary-0.1.5.tar.gz: medialibrary-0.1.5/src/media/xml/namespaces.py <==
#!/usr/bin/env python

#
# Copyright 2022 Chris Josephes
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

'''XML Namespace Constants'''


class Namespaces():
    '''Static data on XML Namespaces'''
    ns = {
            "media": "http://vectortron.com/xml/media/media",
            "movie": "http://vectortron.com/xml/media/movie"
        }

    @classmethod
    def nsf(cls, in_tag):
        '''return the fully qualified namespace to the prefix format'''
        return '{' + Namespaces.ns[in_tag] + '}'

    @classmethod
    def ns_strip(cls, in_tag):
        '''Strip the namespace from an element'''
        out = in_tag.split("}", 1)
        return out[1]

==> medialibrary-0.1.7.tar.gz: medialibrary-0.1.7/src/media/xml/namespaces.py <==
#!/usr/bin/env python

#
# Copyright 2023 Chris Josephes
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

'''XML Namespace Constants'''


class Namespaces():
    '''Static data on XML Namespaces'''
    ns = {
            "media": "http://vectortron.com/xml/media/media",
            "movie": "http://vectortron.com/xml/media/movie",
            "authorship": "http://vectortron.com/xml/media/meta/authorship"
        }

    @classmethod
    def nsf(cls, in_tag):
        '''return the fully qualified namespace to the prefix format'''
        return '{' + Namespaces.ns[in_tag] + '}'

    @classmethod
    def ns_strip(cls, in_tag):
        '''Strip the namespace from an element'''
        out = in_tag.split("}", 1)
        return out[1]
